@@ -48,7 +48,11 @@ def multi_repeat(repeats: List[Tuple[int, str]], method: str) -> str:
         raise ValueError(f"method must be one of AND or OR, not {method}")
 
     to_repeat = [repeat(n, keyword) for (n, keyword) in repeats]
-    return f"{method} ".join(to_repeat)
+
+    if method == "AND":
+        return f"{method} ".join(to_repeat)
+    elif method == "OR":
+        return "(" + f"{method} ".join(to_repeat) + ")"
 
 
 class Filters:
